from ... pyaz_utils import _call_az

def show(profile_name, resource_group, security_policy_name):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - security_policy_name -- Name of the security policy.
    '''
    return _call_az("az afd security-policy show", locals())


def list(profile_name, resource_group):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd security-policy list", locals())


def create(domains, profile_name, resource_group, security_policy_name, waf_policy):
    '''
    Creates a new security policy within the specified profile.

    Required Parameters:
    - domains -- The domains to associate with the WAF policy. Could either be the ID of an endpoint (default domain will be used in that case) or ID of a custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - security_policy_name -- Name of the security policy.
    - waf_policy -- The ID of Front Door WAF policy.
    '''
    return _call_az("az afd security-policy create", locals())


def update(profile_name, resource_group, security_policy_name, domains=None, waf_policy=None):
    '''
    Update an existing security policy within the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - security_policy_name -- Name of the security policy.

    Optional Parameters:
    - domains -- The domains to associate with the WAF policy. Could either be the ID of an endpoint (default domain will be used in that case) or ID of a custom domain.
    - waf_policy -- The ID of Front Door WAF policy.
    '''
    return _call_az("az afd security-policy update", locals())


def delete(profile_name, resource_group, security_policy_name, yes=None):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - security_policy_name -- Name of the security policy.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd security-policy delete", locals())




'''
Manage Batch applications.
'''
from ... pyaz_utils import _call_az
from . import package, summary


def list(name, resource_group, maxresults=None):
    '''
    

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - maxresults -- The maximum number of items to return in the response.
    '''
    return _call_az("az batch application list", locals())


def show(application_name, name, resource_group):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    '''
    return _call_az("az batch application show", locals())


def create(application_name, name, resource_group, parameters=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - parameters -- The parameters for the request.
    '''
    return _call_az("az batch application create", locals())


def set(application_name, name, resource_group, allow_updates=None, default_version=None, display_name=None):
    '''
    Update properties for a Batch application.

    Required Parameters:
    - application_name -- The name of the application.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - allow_updates -- Specify to indicate whether packages within the application may be overwritten using the same version string. Specify either 'true' or 'false' to update the property.
    - default_version -- The package to use if a client requests the application but does not specify a version. This property can only be set to the name of an existing package.
    - display_name -- The display name for the application.
    '''
    return _call_az("az batch application set", locals())


def delete(application_name, name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch application delete", locals())




from .... pyaz_utils import _call_az
from . import event_grid, event_hub, iot_hub


def list(database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of data connections of the given Kusto pool database.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto data-connection list", locals())


def show(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns a data connection.

    Required Parameters:
    - data_connection_name -- The name of the data connection.
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto data-connection show", locals())


def delete(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the data connection with the given name.

    Required Parameters:
    - data_connection_name -- The name of the data connection.
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse kusto data-connection delete", locals())


def wait(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto data-connection is met.

    Required Parameters:
    - data_connection_name -- The name of the data connection.
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse kusto data-connection wait", locals())




from ..... pyaz_utils import _call_az

def list(port_name, resource_group):
    '''
    List ExpressRoute links.

    Required Parameters:
    - port_name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port link list", locals())


def show(name, port_name, resource_group):
    '''
    Get the details of an ExpressRoute link.

    Required Parameters:
    - name -- The link name of the ExpressRoute Port
    - port_name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port link show", locals())


def update(name, port_name, resource_group, add=None, admin_state=None, force_string=None, macsec_cak_secret_identifier=None, macsec_cipher=None, macsec_ckn_secret_identifier=None, macsec_sci_state=None, no_wait=None, remove=None, set=None):
    '''
    Manage MACsec configuration of an ExpressRoute Link.

    Required Parameters:
    - name -- The link name of the ExpressRoute Port
    - port_name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_state -- Enable/Disable administrative state of an ExpressRoute Link
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - macsec_cak_secret_identifier -- The connectivity association key (CAK) ID that stored in the KeyVault.
    - macsec_cipher -- Cipher Method
    - macsec_ckn_secret_identifier -- The connectivity key name (CKN) that stored in the KeyVault.
    - macsec_sci_state -- Sci mode
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network express-route port link update", locals())




'''
Manage the certificate of an application.
'''
from .... pyaz_utils import _call_az

def add(cluster_name, resource_group, certificate_file=None, certificate_output_folder=None, certificate_password=None, certificate_subject_name=None, secret_identifier=None, vault_name=None, vault_rg=None):
    '''
    Add a new certificate to the Virtual Machine Scale Sets that make up the cluster to be used by hosted applications.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - certificate_file -- The existing certificate file path for the primary cluster certificate.
    - certificate_output_folder -- The folder of the new certificate file to be created.
    - certificate_password -- The password of the certificate file.
    - certificate_subject_name -- The subject name of the certificate to be created.
    - secret_identifier -- The existing Azure key vault secret URL
    - vault_name -- Azure key vault name, it not given it will be the cluster resource group name
    - vault_rg -- Key vault resource group name, if not given it will be cluster resource group name
    '''
    return _call_az("az sf application certificate add", locals())




'''
Manage NoSQL key-value storage.
'''
from ... pyaz_utils import _call_az
from . import policy


def create(name, account_key=None, account_name=None, connection_string=None, fail_on_exist=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name --  The name of the table to create. The table name may contain only alphanumeric characters and cannot begin with a numeric character. It is case-insensitive and must be from 3 to 63 characters long.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - fail_on_exist -- Throw an exception if the table already exists.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage table create", locals())


def delete(name, account_key=None, account_name=None, connection_string=None, fail_not_exist=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name --  The name of the table to delete.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - fail_not_exist --  Specifies whether to throw an exception if the table doesn't exist.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage table delete", locals())


def exists(name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name --  The name of table to check for existence.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage table exists", locals())


def generate_sas(name, account_key=None, account_name=None, connection_string=None, end_pk=None, end_rk=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None, start_pk=None, start_rk=None):
    '''
    

    Required Parameters:
    - name --  The name of the table to create a SAS token for.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - end_pk --  The maximum partition key accessible with this shared access signature. endpk must accompany endrk. Key values are inclusive. If omitted, there is no upper bound on the table entities that can be accessed.
    - end_rk --  The maximum row key accessible with this shared access signature. endpk must accompany endrk. Key values are inclusive. If omitted, there is no upper bound on the table entities that can be accessed.
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (r)ead/query (a)dd (u)pdate (d)elete. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy within the table's ACL.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    - start_pk --  The minimum partition key accessible with this shared access signature. startpk must accompany startrk. Key values are inclusive. If omitted, there is no lower bound on the table entities that can be accessed.
    - start_rk --  The minimum row key accessible with this shared access signature. startpk must accompany startrk. Key values are inclusive. If omitted, there is no lower bound on the table entities that can be accessed.
    '''
    return _call_az("az storage table generate-sas", locals())


def list(account_key=None, account_name=None, connection_string=None, marker=None, num_results=None, sas_token=None, timeout=None):
    '''
    List tables in a storage account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - marker --  An opaque continuation object. This value can be retrieved from the next_marker field of a previous generator object if num_results was specified and that generator has finished enumerating results. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results --  The maximum number of tables to return.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage table list", locals())


def stats(account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage table stats", locals())




'''
Manage retention policy for Azure Container Registries.
'''
from .... pyaz_utils import _call_az

def show(registry, resource_group=None):
    '''
    Show the configured retention policy for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr config retention show", locals())


def update(registry, type, days=None, resource_group=None, status=None):
    '''
    Update retention policy for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - type -- The type of retention policy.

    Optional Parameters:
    - days -- The number of days to retain an untagged manifest after which it gets purged (Range: 0 to 365). Value "0" will delete untagged manifests immediately.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - status -- Indicates whether retention policy is enabled.
    '''
    return _call_az("az acr config retention update", locals())




'''
Configure web app settings. Updating or removing application settings will cause an app recycle.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    Get the details of a web app's settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config appsettings list", locals())


def set(name, resource_group, settings=None, slot=None, slot_settings=None):
    '''
    Set a web app's settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - settings -- space-separated appsettings in a format of `<name>=<value>`
    - slot -- the name of the slot. Default to the productions slot if not specified
    - slot_settings -- space-separated slot appsettings in a format of either `<name>=<value>` or `@<json_file>`
    '''
    return _call_az("az webapp config appsettings set", locals())


def delete(name, resource_group, setting_names, slot=None):
    '''
    Delete web app settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - setting_names -- space-separated appsettings names

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config appsettings delete", locals())




from .... pyaz_utils import _call_az

def set(managed_instance, name, resource_group, monthly_retention=None, week_of_year=None, weekly_retention=None, yearly_retention=None):
    '''
    Update long term retention settings for a managed database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - monthly_retention -- Retention for the monthly backup. If just a number is passed instead of an ISO 8601 string, days will be assumed as the units.There is a minimum of 7 days and a maximum of 10 years.
    - week_of_year -- The Week of Year, 1 to 52, in which to take the yearly LTR backup.
    - weekly_retention -- Retention for the weekly backup. If just a number is passed instead of an ISO 8601 string, days will be assumed as the units.There is a minimum of 7 days and a maximum of 10 years.
    - yearly_retention -- Retention for the yearly backup. If just a number is passed instead of an ISO 8601 string, days will be assumed as the units.There is a minimum of 7 days and a maximum of 10 years.
    '''
    return _call_az("az sql midb ltr-policy set", locals())


def show(managed_instance, name, resource_group):
    '''
    Show the long term retention policy for a managed database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb ltr-policy show", locals())




'''
Manage Azure Service Bus namespaces, queues, topics, subscriptions, rules and geo-disaster recovery configuration alias
'''
from .. pyaz_utils import _call_az
from . import georecovery_alias, migration, namespace, queue, topic




'''
Manage Proximity Placement Groups
'''
from .. pyaz_utils import _call_az

def show(name, resource_group, include_colocation_status=None):
    '''
    Get a proximity placement group

    Required Parameters:
    - name -- The name of the proximity placement group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - include_colocation_status -- Enable fetching the colocation status of all the resources in the proximity placement group.
    '''
    return _call_az("az ppg show", locals())


def create(name, resource_group, location=None, tags=None, type=None):
    '''
    Create a proximity placement group

    Required Parameters:
    - name -- The name of the proximity placement group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - type -- The type of the proximity placement group. Allowed values: Standard.
    '''
    return _call_az("az ppg create", locals())


def list(resource_group=None):
    '''
    List proximity placement groups

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ppg list", locals())


def update(name, resource_group, add=None, force_string=None, include_colocation_status=None, remove=None, set=None):
    '''
    Update a proximity placement group

    Required Parameters:
    - name -- The name of the proximity placement group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - include_colocation_status -- includeColocationStatus=true enables fetching the colocation status of all the resources in the proximity placement group.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az ppg update", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the proximity placement group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ppg delete", locals())




'''
Inspect the marketplace usage data of an Azure subscription within a billing period.
'''
from ... pyaz_utils import _call_az

def list(billing_period_name=None, end_date=None, start_date=None, top=None):
    '''
    List the marketplace for an Azure subscription within a billing period.

    Optional Parameters:
    - billing_period_name -- Name of the billing period to get the marketplace.
    - end_date -- End date (YYYY-MM-DD in UTC). If specified, also requires --start-date.
    - start_date -- Start date (YYYY-MM-DD in UTC). If specified, also requires --end-date.
    - top -- Maximum number of items to return. Value range: 1-1000.
    '''
    return _call_az("az consumption marketplace list", locals())




from ... pyaz_utils import _call_az

def list(id=None, name=None, resource_group=None, type=None):
    '''
    List all private link resources.

    Optional Parameters:
    - id -- ID of the resource
    - name -- Name of the resource. If provided, --type and --resource-group must be provided too
    - resource_group -- Name of resource group. If provided, --name and --type must be provided too
    - type -- Type of the resource. If provided, --name and --resource-group must be provided too
    '''
    return _call_az("az network private-link-resource list", locals())




'''
Manage ssh public key with vm
'''
from .. pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List all of the SSH public keys.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sshkey list", locals())


def show(name, resource_group):
    '''
    Retrieve information about an SSH public key.

    Required Parameters:
    - name -- The name of the SSH public key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sshkey show", locals())


def create(name, resource_group, location=None, public_key=None, tags=None):
    '''
    Create a new SSH public key resource.

    Required Parameters:
    - name -- The name of the SSH public key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - public_key -- SSH public key used to authenticate to a virtual machine through ssh. If this property is not initially provided when the resource is created, the publicKey property will be populated when generateKeyPair is called. If the public key is provided upon resource creation, the provided public key needs to be at least 2048-bit and in ssh-rsa format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sshkey create", locals())


def update(name, resource_group, public_key=None, tags=None):
    '''
    Update an SSH public key resource.

    Required Parameters:
    - name -- The name of the SSH public key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - public_key -- SSH public key used to authenticate to a virtual machine through ssh. If this property is not initially provided when the resource is created, the publicKey property will be populated when generateKeyPair is called. If the public key is provided upon resource creation, the provided public key needs to be at least 2048-bit and in ssh-rsa format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sshkey update", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an SSH public key.

    Required Parameters:
    - name -- The name of the SSH public key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sshkey delete", locals())




'''
Manage appliations for VM
'''
from ... pyaz_utils import _call_az

def set(app_version_ids, name, resource_group, app_config_overrides=None, order_applications=None):
    '''
    Set appliations for VM.

    Required Parameters:
    - app_version_ids -- Space-separated application version ids to set to VM.
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - app_config_overrides -- Space-separated application configuration overrides for each application version ids. It should have the same number of items as the application version ids. Null is available for a application which does not have a configuration override.
    - order_applications -- Whether set order index at each gallery applications, the order index starts from 1.
    '''
    return _call_az("az vm application set", locals())


def list(resource_group, vm_name):
    '''
    List applications for VM

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm application list", locals())




'''
Manage container metadata.
'''
from .... pyaz_utils import _call_az

def update(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  If specified, set_container_metadata only succeeds if the container's lease is active and matches this ID.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container metadata update", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - lease_id --  If specified, get_container_metadata only succeeds if the container's lease is active and matches this ID.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container metadata show", locals())




from .... pyaz_utils import _call_az

def show(id=None, name=None, resource_group=None, scope_name=None):
    '''
    Show a private endpoint connection of a private link scope resource.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the private link scope. You can get it using `az monitor private-link-scope show`.
    - name -- The name of the private endpoint connection associated with the private link scope.
    - resource_group -- The resource group name of specified private link scope.
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-endpoint-connection show", locals())


def list(resource_group, scope_name):
    '''
    List all private endpoint connections of a private link scope resource.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-endpoint-connection list", locals())


def approve(description=None, id=None, name=None, resource_group=None, scope_name=None):
    '''
    Approve a private endpoint connection of a private link scope resource.

    Optional Parameters:
    - description -- Comments for approve operation.
    - id -- The ID of the private endpoint connection associated with the private link scope. You can get it using `az monitor private-link-scope show`.
    - name -- The name of the private endpoint connection associated with the private link scope.
    - resource_group -- The resource group name of specified private link scope.
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, scope_name=None):
    '''
    Reject a private endpoint connection of a private link scope resource.

    Optional Parameters:
    - description -- Comments for reject operation.
    - id -- The ID of the private endpoint connection associated with the private link scope. You can get it using `az monitor private-link-scope show`.
    - name -- The name of the private endpoint connection associated with the private link scope.
    - resource_group -- The resource group name of specified private link scope.
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, scope_name=None, yes=None):
    '''
    Delete a private endpoint connection of a private link scope resource.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the private link scope. You can get it using `az monitor private-link-scope show`.
    - name -- The name of the private endpoint connection associated with the private link scope.
    - resource_group -- The resource group name of specified private link scope.
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor private-link-scope private-endpoint-connection delete", locals())




from ... pyaz_utils import _call_az

def rerun(name, run_id, workspace_name):
    '''
    Rerun single trigger instance by runId.

    Required Parameters:
    - name -- The trigger name.
    - run_id -- The trigger run identifier.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse trigger-run rerun", locals())


def cancel(name, run_id, workspace_name):
    '''
    Cancel a single trigger instance by runId.

    Required Parameters:
    - name -- The trigger name.
    - run_id -- The trigger run identifier.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse trigger-run cancel", locals())


def query_by_workspace(last_updated_after, last_updated_before, workspace_name, continuation_token=None, filters=None, order_by=None):
    '''
    Query trigger runs in the workspace based on input filter conditions.

    Required Parameters:
    - last_updated_after -- The time at or after which the run event was updated in 'ISO 8601' format.
    - last_updated_before -- The time at or before which the run event was updated in 'ISO 8601' format.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - continuation_token -- The continuation token for getting the next page of results. Null for first page.
    - filters -- List of filters.
    - order_by -- List of OrderBy option.
    '''
    return _call_az("az synapse trigger-run query-by-workspace", locals())




'''
Manage blob metadata.
'''
from .... pyaz_utils import _call_az

def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  The snapshot parameter is an opaque value that, when present, specifies the blob snapshot to retrieve.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob metadata show", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob metadata update", locals())




'''
Manage Azure Maps accounts.
'''
from ... pyaz_utils import _call_az
from . import keys


def show(name, resource_group):
    '''
    Show the details of a maps account.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps account show", locals())


def list(resource_group=None):
    '''
    Show all maps accounts in a subscription or in a resource group.

    Optional Parameters:
    - resource_group -- Resource group name
    '''
    return _call_az("az maps account list", locals())


def create(name, resource_group, sku, accept_tos=None, disable_local_auth=None, kind=None, linked_resources=None, tags=None, type=None, user_identities=None):
    '''
    Create a Maps Account. A Maps Account holds the keys which allow access to the Maps REST APIs.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    - sku -- The name of the SKU, in standard format (such as S0).

    Optional Parameters:
    - accept_tos -- You must agree to the License and Privacy Statement to create an account.
    - disable_local_auth -- Allows toggle functionality on Azure Policy to disable Azure Maps local authentication support. This will disable Shared Keys authentication from any usage.
    - kind -- Get or Set Kind property.
    - linked_resources -- Sets the resources to be used for Managed Identities based operations for the Map account resource.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - type -- The identity type.
    - user_identities -- The list of user identities associated with the resource. The user identity dictionary key references will be ARM resource ids in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}'. Expected value: json-string/@json-file.
    '''
    return _call_az("az maps account create", locals())


def delete(name, resource_group):
    '''
    Delete a Maps Account.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps account delete", locals())


def update(name, resource_group, sku, disable_local_auth=None, kind=None, linked_resources=None, tags=None, type=None, user_identities=None):
    '''
    Updates a Maps Account. Only a subset of the parameters may be updated after creation, such as Sku, Tags, Properties.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    - sku -- The name of the SKU, in standard format (such as S0).

    Optional Parameters:
    - disable_local_auth -- Allows toggle functionality on Azure Policy to disable Azure Maps local authentication support. This will disable Shared Keys authentication from any usage.
    - kind -- Get or Set Kind property.
    - linked_resources -- Sets the resources to be used for Managed Identities based operations for the Map account resource.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - type -- The identity type.
    - user_identities -- The list of user identities associated with the resource. The user identity dictionary key references will be ARM resource ids in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}'. Expected value: json-string/@json-file.
    '''
    return _call_az("az maps account update", locals())




'''
billing policy
'''
from ... pyaz_utils import _call_az

def update(account_name, customer_name=None, marketplace_purchases=None, profile_name=None, reservation_purchases=None, view_charges=None):
    '''
    Update the policies for a billing profile. This operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - customer_name -- The ID that uniquely identifies a customer
    - marketplace_purchases -- The policy that controls whether Azure marketplace purchases are allowed for a billing profile.
    - profile_name -- The ID that uniquely identifies a billing profile.
    - reservation_purchases -- The policy that controls whether Azure reservation purchases are allowed for a billing profile.
    - view_charges -- The policy that controls whether users with Azure RBAC access to a subscription can view its charges.
    '''
    return _call_az("az billing policy update", locals())


def show(account_name, customer_name=None, profile_name=None):
    '''
    Show the policies for a customer or for a billing profile. This operation is supported only for billing accounts with agreement type Microsoft Partner Agreement."

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account

    Optional Parameters:
    - customer_name -- The ID that uniquely identifies a customer
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing policy show", locals())




'''
Manage SQL virtual machine groups.
'''
from .... pyaz_utils import _call_az
from . import ag_listener


def update(name, resource_group, add=None, bootstrap_acc=None, domain_fqdn=None, force_string=None, fsw_path=None, operator_acc=None, ou_path=None, remove=None, sa_key=None, service_acc=None, set=None, storage_account=None, tags=None):
    '''
    Updates a SQL virtual machine group if there are not SQL virtual machines attached to the group.

    Required Parameters:
    - name -- Name of the SQL virtual machine group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - bootstrap_acc -- Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
    - domain_fqdn -- Fully qualified name of the domain.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - fsw_path -- Optional path for fileshare witness.
    - operator_acc -- Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
    - ou_path -- Organizational Unit path in which the nodes and cluster will be present. Example: OU=WSCluster,DC=testdomain,DC=com
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - sa_key -- Primary key of the witness storage account.
    - service_acc -- Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - storage_account -- Storage account url of the witness storage account.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sql vm group update", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the SQL virtual machine group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm group show", locals())


def list(resource_group=None):
    '''
    

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm group list", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the SQL virtual machine group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql vm group delete", locals())


def create(domain_fqdn, image_offer, image_sku, name, operator_acc, resource_group, service_acc, storage_account, bootstrap_acc=None, fsw_path=None, location=None, ou_path=None, sa_key=None, tags=None):
    '''
    Creates a SQL virtual machine group.

    Required Parameters:
    - domain_fqdn -- Fully qualified name of the domain.
    - image_offer -- SQL image offer. Examples may include SQL2016-WS2016, SQL2017-WS2016.
    - image_sku -- SQL image sku.
    - name -- Name of the SQL virtual machine group.
    - operator_acc -- Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_acc -- Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
    - storage_account -- Storage account url of the witness storage account.

    Optional Parameters:
    - bootstrap_acc -- Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
    - fsw_path -- Optional path for fileshare witness.
    - location -- Location. If not provided, group will be created in the same reosurce group location.You can configure the default location using `az configure --defaults location=<location>`.
    - ou_path -- Organizational Unit path in which the nodes and cluster will be present. Example: OU=WSCluster,DC=testdomain,DC=com
    - sa_key -- Primary key of the witness storage account.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sql vm group create", locals())




'''
Manage the Facebook Channel on a bot.
'''
from ... pyaz_utils import _call_az

def create(appid, name, page_id, resource_group, secret, token, add_disabled=None):
    '''
    Create the Facebook Channel on a bot.

    Required Parameters:
    - appid -- The Facebook application id.
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - page_id -- Page ID of the Facebook page to be used for the bot.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret -- The Facebook application secret.
    - token -- The Facebook application access token.

    Optional Parameters:
    - add_disabled -- Add the channel in a disabled state
    '''
    return _call_az("az bot facebook create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Facebook Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - with_secrets -- Show secrets in response for the channel.
    '''
    return _call_az("az bot facebook show", locals())


def delete(name, resource_group):
    '''
    Delete the Facebook Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az bot facebook delete", locals())




from ... pyaz_utils import _call_az

def query_by_pipeline_run(last_updated_after, last_updated_before, name, run_id, workspace_name, continuation_token=None, filters=None, order_by=None):
    '''
    Query activity runs based on input filter conditions.

    Required Parameters:
    - last_updated_after -- The time at or after which the run event was updated in 'ISO 8601' format.
    - last_updated_before -- The time at or before which the run event was updated in 'ISO 8601' format.
    - name -- The pipeline name.
    - run_id -- The pipeline run identifier.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - continuation_token -- The continuation token for getting the next page of results. Null for first page.
    - filters -- List of filters.
    - order_by -- List of OrderBy option.
    '''
    return _call_az("az synapse activity-run query-by-pipeline-run", locals())




'''
Manage assets for an Azure Media Services account.
'''
from ... pyaz_utils import _call_az

def show(account_name, name, resource_group):
    '''
    Show the details of an asset.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset show", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the assets of an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- Restricts the set of items returned.
    - orderby -- Specifies the key by which the result collection should be ordered.
    - top -- Specifies a non-negative integer n that limits the number of items returned from a collection. The service returns the number of available items up to but not greater than the specified value n.
    '''
    return _call_az("az ams asset list", locals())


def delete(account_name, name, resource_group):
    '''
    Delete an asset.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset delete", locals())


def list_streaming_locators(account_name, name, resource_group):
    '''
    List streaming locators which are associated with this asset.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset list-streaming-locators", locals())


def get_encryption_key(account_name, name, resource_group):
    '''
    Get the asset storage encryption keys used to decrypt content created by version 2 of the Media Services API.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset get-encryption-key", locals())


def update(account_name, name, resource_group, add=None, alternate_id=None, description=None, force_string=None, remove=None, set=None):
    '''
    Update the details of an asset.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - alternate_id -- The alternate id of the asset.
    - description -- The asset description.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az ams asset update", locals())


def get_sas_urls(account_name, name, resource_group, expiry=None, permissions=None):
    '''
    Lists storage container URLs with shared access signatures (SAS) for uploading and downloading Asset content. The signatures are derived from the storage account keys.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M:S'Z') at which the SAS becomes invalid. This must be less than 24 hours from the current time.
    - permissions -- The permissions to set on the SAS URL.
    '''
    return _call_az("az ams asset get-sas-urls", locals())


def create(account_name, name, resource_group, alternate_id=None, container=None, description=None, storage_account=None):
    '''
    Create an asset.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - alternate_id -- The alternate id of the asset.
    - container -- The name of the asset blob container.
    - description -- The asset description.
    - storage_account -- The name of the storage account.
    '''
    return _call_az("az ams asset create", locals())




'''
Manage billing profile of billing account
'''
from ... pyaz_utils import _call_az

def list(account_name, expand=None):
    '''
    List the billing profiles that a user has access to. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - expand -- May be used to expand the invoice sections.
    '''
    return _call_az("az billing profile list", locals())


def show(account_name, name, expand=None):
    '''
    Get a billing profile by its ID. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - expand -- May be used to expand the invoice sections.
    '''
    return _call_az("az billing profile show", locals())


def create(account_name, name, bill_to=None, display_name=None, enabled_azure_plans=None, invoice_email_opt_in=None, invoice_sections_value=None, no_wait=None, po_number=None):
    '''
    Creates or updates a billing profile. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - bill_to -- Billing address.
    - display_name -- The name of the billing profile.
    - enabled_azure_plans -- Information about the enabled azure plans.
    - invoice_email_opt_in -- Flag controlling whether the invoices for the billing profile are sent through email.
    - invoice_sections_value -- The invoice sections associated to the billing profile. Expected value: json-string/@json-file.
    - no_wait -- Do not wait for the long-running operation to finish.
    - po_number -- The purchase order name that will appear on the invoices generated for the billing profile.
    '''
    return _call_az("az billing profile create", locals())


def update(account_name, name, bill_to=None, display_name=None, enabled_azure_plans=None, invoice_email_opt_in=None, invoice_sections_value=None, no_wait=None, po_number=None):
    '''
    Creates or updates a billing profile. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - bill_to -- Billing address.
    - display_name -- The name of the billing profile.
    - enabled_azure_plans -- Information about the enabled azure plans.
    - invoice_email_opt_in -- Flag controlling whether the invoices for the billing profile are sent through email.
    - invoice_sections_value -- The invoice sections associated to the billing profile. Expected value: json-string/@json-file.
    - no_wait -- Do not wait for the long-running operation to finish.
    - po_number -- The purchase order name that will appear on the invoices generated for the billing profile.
    '''
    return _call_az("az billing profile update", locals())


def wait(account_name, name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing profile is met.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- May be used to expand the invoice sections.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az billing profile wait", locals())




from .... pyaz_utils import _call_az

def start(managed_instance, name, resource_group, storage_sas, storage_uri, auto_complete=None, last_backup_name=None, no_wait=None):
    '''
    Start Log Replay service on specified database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_sas -- The authorization Sas token to access storage container where backups are.
    - storage_uri -- The URI of the storage container where backups are.

    Optional Parameters:
    - auto_complete -- The flag that in usage with last_backup_name automatically completes log replay servise.
    - last_backup_name -- The name of the last backup to restore.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql midb log-replay start", locals())


def stop(managed_instance, name, resource_group, no_wait=None, yes=None):
    '''
    Stop Log Replay service.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql midb log-replay stop", locals())


def complete(managed_instance, name, resource_group, last_backup_name=None):
    '''
    Complete Log Replay service on specified database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - last_backup_name -- The name of the last backup to restore.
    '''
    return _call_az("az sql midb log-replay complete", locals())


def wait(managed_instance, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the managed database is met.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql midb log-replay wait", locals())


def show(managed_instance, name, resource_group):
    '''
    Get status of Log Replay service.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb log-replay show", locals())




from .... pyaz_utils import _call_az

def create(name, remote_vnet, resource_group, workspace_name, allow_forwarded_traffic=None, allow_gateway_transit=None, allow_virtual_network_access=None, no_wait=None, use_remote_gateways=None):
    '''
    Create a vnet peering for a workspace.

    Required Parameters:
    - name -- The name of the vnet peering.
    - remote_vnet -- The remote virtual network name or Resource ID.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - allow_forwarded_traffic -- Whether the forwarded traffic from the VMs in the local virtual network will be allowed/disallowed in remote virtual network.
    - allow_gateway_transit -- If gateway links can be used in remote virtual networking to link to this virtual network.
    - allow_virtual_network_access -- Whether the VMs in the local virtual network space would be able to access the VMs in remote virtual network space.
    - no_wait -- Do not wait for the long-running operation to finish.
    - use_remote_gateways -- If remote gateways can be used on this virtual network. If the flag is set to true, and allowGatewayTransit on remote peering is also true, virtual network will use gateways of remote virtual network for transit. Only one peering can have this flag set to true. This flag cannot be set if virtual network already has a gateway.
    '''
    return _call_az("az databricks workspace vnet-peering create", locals())


def update(name, resource_group, workspace_name, allow_forwarded_traffic=None, allow_gateway_transit=None, allow_virtual_network_access=None, no_wait=None, use_remote_gateways=None):
    '''
    Update the vnet peering.

    Required Parameters:
    - name -- The name of the vnet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - allow_forwarded_traffic -- Whether the forwarded traffic from the VMs in the local virtual network will be allowed/disallowed in remote virtual network.
    - allow_gateway_transit -- If gateway links can be used in remote virtual networking to link to this virtual network.
    - allow_virtual_network_access -- Whether the VMs in the local virtual network space would be able to access the VMs in remote virtual network space.
    - no_wait -- Do not wait for the long-running operation to finish.
    - use_remote_gateways -- If remote gateways can be used on this virtual network. If the flag is set to true, and allowGatewayTransit on remote peering is also true, virtual network will use gateways of remote virtual network for transit. Only one peering can have this flag set to true. This flag cannot be set if virtual network already has a gateway.
    '''
    return _call_az("az databricks workspace vnet-peering update", locals())


def delete(name, resource_group, workspace_name, no_wait=None):
    '''
    Delete the vnet peering.

    Required Parameters:
    - name -- The name of the vnet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az databricks workspace vnet-peering delete", locals())


def list(resource_group, workspace_name):
    '''
    List vnet peerings under a workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az databricks workspace vnet-peering list", locals())


def show(name, resource_group, workspace_name):
    '''
    Show the vnet peering.

    Required Parameters:
    - name -- The name of the vnet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az databricks workspace vnet-peering show", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Databricks workspace vnet peering is met.

    Required Parameters:
    - name -- The name of the vnet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az databricks workspace vnet-peering wait", locals())




'''
Manage autoscale scaling rules.
'''
from .... pyaz_utils import _call_az

def create(autoscale_name, condition, scale, cooldown=None, profile_name=None, resource=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, timegrain=None):
    '''
    Add a new autoscale rule.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - condition -- Condition on which to scale.
    - scale -- The direction and amount to scale.

    Optional Parameters:
    - cooldown -- The number of minutes that must elapse before another scaling event can occur.
    - profile_name -- Name of the autoscale profile.
    - resource -- Name or ID of the target resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - timegrain -- None
    '''
    return _call_az("az monitor autoscale rule create", locals())


def list(autoscale_name, resource_group, profile_name=None):
    '''
    List autoscale rules for a profile.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - profile_name -- Name of the autoscale profile.
    '''
    return _call_az("az monitor autoscale rule list", locals())


def delete(autoscale_name, index, resource_group, profile_name=None):
    '''
    Remove autoscale rules from a profile.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - index -- Space-separated list of rule indices to remove, or '*' to clear all rules.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - profile_name -- Name of the autoscale profile.
    '''
    return _call_az("az monitor autoscale rule delete", locals())


def copy(autoscale_name, dest_schedule, index, resource_group, source_schedule=None):
    '''
    Copy autoscale rules from one profile to another.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - dest_schedule -- Name of the profile to copy rules to.
    - index -- Space-separated list of rule indices to copy, or '*' to copy all rules.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - source_schedule -- Name of the profile to copy rules from.
    '''
    return _call_az("az monitor autoscale rule copy", locals())




'''
Manage container registry encryption
'''
from ... pyaz_utils import _call_az

def show(name, resource_group=None):
    '''
    Show the container registry's encryption details

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr encryption show", locals())


def rotate_key(name, identity=None, key_encryption_key=None, resource_group=None):
    '''
    Rotate (update) the container registry's encryption key

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - identity -- client id of managed identity, resource name or id of user assigned identity. Use '[system]' to refer to the system assigned identity
    - key_encryption_key -- Key vault key uri. To enable automated rotation, provide a version-less key uri. For manual rotation, provide a versioned key uri.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr encryption rotate-key", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    List of secure-scores details and state results.
    '''
    return _call_az("az security secure-scores list", locals())


def show(name):
    '''
    Shows a secure score details for selected initiative.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security secure-scores show", locals())




'''
Manage storage account keys.
'''
from .... pyaz_utils import _call_az

def renew(account_name, key, key_type=None, resource_group=None):
    '''
    Regenerate one of the access keys or Kerberos keys (if active directory enabled) for a storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - key -- The key options to regenerate.

    Optional Parameters:
    - key_type -- The key type to regenerate. If --key-type is not specified, one of access keys will be regenerated by default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account keys renew", locals())


def list(account_name, expand_key_type=None, resource_group=None):
    '''
    List the access keys or Kerberos keys (if active directory enabled) for a storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - expand_key_type -- Specify the expanded key types to be listed.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account keys list", locals())




from .... pyaz_utils import _call_az

def show(account_name, container_name, if_match=None, resource_group=None):
    '''
    

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
    - container_name -- The container name.

    Optional Parameters:
    - if_match -- The entity state (ETag) version of the immutability policy to update. A value of "*" can be used to apply the operation only if the immutability policy already exists. If omitted, this operation will always be applied.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container immutability-policy show", locals())


def create(account_name, container_name, allow_protected_append_writes=None, allow_protected_append_writes_all=None, if_match=None, period=None, resource_group=None):
    '''
    Create or update an unlocked immutability policy.

    Required Parameters:
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT.
    - container_name -- The container name.

    Optional Parameters:
    - allow_protected_append_writes -- This property can only be changed for unlocked time-based retention policies. When enabled, new blocks can be written to an append blob while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted. This property cannot be changed with ExtendImmutabilityPolicy API.
    - allow_protected_append_writes_all -- This property can only be changed for unlocked time-based retention policies. When enabled, new blocks can be written to both 'Append and Block Blobs' while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted. This property cannot be changed with ExtendImmutabilityPolicy API. The 'allowProtectedAppendWrites' and 'allowProtectedAppendWritesAll' properties are mutually exclusive.
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - period -- The immutability period for the blobs in the container since the policy creation, in days.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container immutability-policy create", locals())


def delete(account_name, container_name, if_match, resource_group=None):
    '''
    

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
    - container_name -- The container name.
    - if_match -- The entity state (ETag) version of the immutability policy to update. A value of "*" can be used to apply the operation only if the immutability policy already exists. If omitted, this operation will always be applied.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container immutability-policy delete", locals())


def lock(account_name, container_name, if_match, resource_group=None):
    '''
    

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
    - container_name -- The container name.
    - if_match -- The entity state (ETag) version of the immutability policy to update. A value of "*" can be used to apply the operation only if the immutability policy already exists. If omitted, this operation will always be applied.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container immutability-policy lock", locals())


def extend(account_name, container_name, if_match, allow_protected_append_writes=None, allow_protected_append_writes_all=None, period=None, resource_group=None):
    '''
    Extend the immutabilityPeriodSinceCreationInDays of a locked immutabilityPolicy.

    Required Parameters:
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT.
    - container_name -- The container name.
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.

    Optional Parameters:
    - allow_protected_append_writes -- This property can only be changed for unlocked time-based retention policies. When enabled, new blocks can be written to an append blob while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted. This property cannot be changed with ExtendImmutabilityPolicy API.
    - allow_protected_append_writes_all -- This property can only be changed for unlocked time-based retention policies. When enabled, new blocks can be written to both 'Append and Block Blobs' while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted. This property cannot be changed with ExtendImmutabilityPolicy API. The 'allowProtectedAppendWrites' and 'allowProtectedAppendWritesAll' properties are mutually exclusive.
    - period -- The immutability period for the blobs in the container since the policy creation, in days.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container immutability-policy extend", locals())




from ..... pyaz_utils import _call_az

def update(group_name, name, resource_group, add=None, force_string=None, remove=None, set=None, sqlvms=None):
    '''
    Updates an availability group listener.

    Required Parameters:
    - group_name -- Name of the SQL virtual machine group.
    - name -- Name of the availability group listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sqlvms -- Space-separated list of SQL virtual machine instance name or resource IDs that are enrolled into the availability group.
    '''
    return _call_az("az sql vm group ag-listener update", locals())


def show(group_name, name, resource_group):
    '''
    

    Required Parameters:
    - group_name -- Name of the SQL virtual machine group.
    - name -- Name of the availability group listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm group ag-listener show", locals())


def list(group_name, resource_group):
    '''
    

    Required Parameters:
    - group_name -- Name of the SQL virtual machine group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm group ag-listener list", locals())


def delete(group_name, name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - group_name -- Name of the SQL virtual machine group.
    - name -- Name of the availability group listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql vm group ag-listener delete", locals())


def create(ag_name, group_name, ip_address, load_balancer, name, probe_port, resource_group, sqlvms, subnet, port=None, public_ip=None, vnet_name=None):
    '''
    Creates an availability group listener.

    Required Parameters:
    - ag_name -- Name of the availability group. Please refer to https://docs.microsoft.com/sql/database-engine/availability-groups/windows/use-the-availability-group-wizard-sql-server-management-studio?view=sql-server-2017 to create and availability group
    - group_name -- Name of the SQL virtual machine group.
    - ip_address -- Private IP address bound to the availability group listener.
    - load_balancer -- Name or resource ID of the load balancer.
    - name -- Name of the availability group listener.
    - probe_port -- Probe port.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sqlvms -- Space-separated list of SQL virtual machine instance name or resource IDs that are enrolled into the availability group.
    - subnet -- The name or resource id of the subnet to include in the private IP.

    Optional Parameters:
    - port -- Listener port.
    - public_ip -- Name or resource ID of the public IP.
    - vnet_name -- Name of the virtual network. Provide only if name of the subnet has been provided.
    '''
    return _call_az("az sql vm group ag-listener create", locals())




from ... pyaz_utils import _call_az
from . import auth, gateway, peering, port


def delete(name, resource_group, no_wait=None):
    '''
    Delete an ExpressRoute circuit.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network express-route delete", locals())


def show(name, resource_group):
    '''
    Get the details of an ExpressRoute circuit.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route show", locals())


def get_stats(name, resource_group):
    '''
    Get the statistics of an ExpressRoute circuit.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route get-stats", locals())


def list_arp_tables(name, path, peering_name, resource_group):
    '''
    Show the current Address Resolution Protocol (ARP) table of an ExpressRoute circuit.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - path -- The path of the device
    - peering_name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route list-arp-tables", locals())


def list_route_tables(name, path, peering_name, resource_group):
    '''
    Show the current routing table of an ExpressRoute circuit peering.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - path -- The path of the device
    - peering_name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route list-route-tables", locals())


def list_route_tables_summary(name, path, peering_name, resource_group):
    '''
    Show the current routing table summary of an ExpressRoute circuit peering.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - path -- The path of the device
    - peering_name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route list-route-tables-summary", locals())


def create(bandwidth, name, peering_location, provider, resource_group, allow_classic_operations=None, allow_global_reach=None, express_route_port=None, location=None, no_wait=None, sku_family=None, sku_tier=None, tags=None):
    '''
    Create an ExpressRoute circuit.

    Required Parameters:
    - bandwidth -- Bandwidth of the circuit. Usage: INT {Mbps,Gbps}. Defaults to Mbps
    - name -- ExpressRoute circuit name.
    - peering_location -- Name of the peering location.
    - provider -- Name of the ExpressRoute Service Provider.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allow_classic_operations -- Allow classic operations.
    - allow_global_reach -- Enable global reach on the circuit.
    - express_route_port -- Name or ID of an ExpressRoute port.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku_family -- Chosen SKU family of ExpressRoute circuit.
    - sku_tier -- SKU Tier of ExpressRoute circuit.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network express-route create", locals())


def list(resource_group=None):
    '''
    List all ExpressRoute circuits for the current subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route list", locals())


def list_service_providers():
    '''
    List available ExpressRoute service providers.
    '''
    return _call_az("az network express-route list-service-providers", locals())


def update(name, resource_group, add=None, allow_classic_operations=None, allow_global_reach=None, bandwidth=None, express_route_port=None, force_string=None, no_wait=None, peering_location=None, provider=None, remove=None, set=None, sku_family=None, sku_tier=None, tags=None):
    '''
    Update settings of an ExpressRoute circuit.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allow_classic_operations -- Allow classic operations.
    - allow_global_reach -- Enable global reach on the circuit.
    - bandwidth -- Bandwidth of the circuit. Usage: INT {Mbps,Gbps}. Defaults to Mbps
    - express_route_port -- Name or ID of an ExpressRoute port.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - peering_location -- Name of the peering location.
    - provider -- Name of the ExpressRoute Service Provider.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku_family -- Chosen SKU family of ExpressRoute circuit.
    - sku_tier -- SKU Tier of ExpressRoute circuit.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network express-route update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the ExpressRoute is met.

    Required Parameters:
    - name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network express-route wait", locals())




'''
Manage container stored access policies.
'''
from .... pyaz_utils import _call_az

def create(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry=None, lease_id=None, permissions=None, sas_token=None, start=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The stored access policy name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry -- expiration UTC datetime in (Y-m-d'T'H:M:S'Z')
    - lease_id -- The container lease ID.
    - permissions -- Allowed values: (a)dd (c)reate (d)elete (l)ist (r)ead (w)rite (a)dd (c)reate (d)elete (l)ist (r)ead (w)rite. Can be combined
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - start -- start UTC datetime (Y-m-d'T'H:M:S'Z'). Defaults to time of request.
    '''
    return _call_az("az storage container policy create", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The stored access policy name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - lease_id -- The container lease ID.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage container policy delete", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry=None, lease_id=None, permissions=None, sas_token=None, start=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The stored access policy name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry -- expiration UTC datetime in (Y-m-d'T'H:M:S'Z')
    - lease_id -- The container lease ID.
    - permissions -- Allowed values: (a)dd (c)reate (d)elete (l)ist (r)ead (w)rite (a)dd (c)reate (d)elete (l)ist (r)ead (w)rite. Can be combined
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - start -- start UTC datetime (Y-m-d'T'H:M:S'Z'). Defaults to time of request.
    '''
    return _call_az("az storage container policy update", locals())


def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The stored access policy name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - lease_id -- The container lease ID.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage container policy show", locals())


def list(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - lease_id -- The container lease ID.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage container policy list", locals())




'''
Manage a service principal's credentials.
'''
from .... pyaz_utils import _call_az

def reset(name, append=None, cert=None, create_cert=None, credential_description=None, end_date=None, keyvault=None, password=None, years=None):
    '''
    Reset a service principal credential.

    Required Parameters:
    - name -- None

    Optional Parameters:
    - append -- Append the new credential instead of overwriting.
    - cert -- None
    - create_cert -- None
    - credential_description -- the description of the password
    - end_date -- Finer grain of expiry time if '--years' is insufficient, e.g. '2020-12-31T11:59:59+00:00' or '2299-12-31'
    - keyvault -- None
    - password -- If missing, CLI will generate a strong password
    - years -- None
    '''
    return _call_az("az ad sp credential reset", locals())


def list(id, cert=None):
    '''
    List a service principal's credentials.

    Required Parameters:
    - id -- service principal name, or object id

    Optional Parameters:
    - cert -- a certificate based credential
    '''
    return _call_az("az ad sp credential list", locals())


def delete(id, key_id, cert=None):
    '''
    Delete a service principal's credential.

    Required Parameters:
    - id -- service principal name, or object id
    - key_id -- credential key id

    Optional Parameters:
    - cert -- a certificate based credential
    '''
    return _call_az("az ad sp credential delete", locals())




'''
Manage image builder template customizers.
'''
from .... pyaz_utils import _call_az

def add(customizer_name, name, resource_group, type, dest_path=None, exit_codes=None, file_source=None, filters=None, inline_script=None, restart_check_command=None, restart_command=None, restart_timeout=None, script_url=None, search_criteria=None, update_limit=None):
    '''
    Add an image builder customizer to an image builder template.

    Required Parameters:
    - customizer_name -- Name of the customizer.
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Type of customizer to be added to the image template.

    Optional Parameters:
    - dest_path -- The absolute destination path where the file specified in --file-source will be downloaded to in the image
    - exit_codes -- Space-separated list of valid exit codes, as integers
    - file_source -- The URI of the file to be downloaded into the image. It can be a github link, SAS URI for Azure Storage, etc.
    - filters -- Space delimited filters to select updates to apply. Omit or specify empty array to use the default (no filter)
    - inline_script -- Space-separated list of inline script lines to customize the image with.
    - restart_check_command -- Command to verify that restart succeeded.
    - restart_command -- Command to execute the restart operation.
    - restart_timeout -- Restart timeout specified as a string consisting of a magnitude and unit, e.g. '5m' (5 minutes) or '2h' (2 hours)
    - script_url -- URL of script to customize the image with. The URL must be publicly accessible.
    - search_criteria -- Criteria to search updates. Omit or specify empty string to use the default (search all). Refer to above link for examples and detailed description of this field.
    - update_limit -- Maximum number of updates to apply at a time. Omit or specify 0 to use the default (1000)
    '''
    return _call_az("az image builder customizer add", locals())


def remove(customizer_name, name, resource_group):
    '''
    Remove an image builder customizer from an image builder template.

    Required Parameters:
    - customizer_name -- Name of the customizer.
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder customizer remove", locals())


def clear(name, resource_group):
    '''
    Remove all image builder customizers from an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder customizer clear", locals())




'''
Manage peering connections between Azure Virtual Networks.
'''
from .... pyaz_utils import _call_az

def create(name, remote_vnet, resource_group, vnet_name, allow_forwarded_traffic=None, allow_gateway_transit=None, allow_vnet_access=None, use_remote_gateways=None):
    '''
    Create a virtual network peering connection.

    Required Parameters:
    - name -- The name of the VNet peering.
    - remote_vnet -- Resource ID or name of the remote VNet.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.

    Optional Parameters:
    - allow_forwarded_traffic -- Allows forwarded traffic from the local VNet to the remote VNet.
    - allow_gateway_transit -- Allows gateway link to be used in the remote VNet.
    - allow_vnet_access -- Allows access from the local VNet to the remote VNet.
    - use_remote_gateways -- Allows VNet to use the remote VNet's gateway. Remote VNet gateway must have --allow-gateway-transit enabled for remote peering. Only 1 peering can have this flag enabled. Cannot be set if the VNet already has a gateway.
    '''
    return _call_az("az network vnet peering create", locals())


def show(name, resource_group, vnet_name):
    '''
    Show details of a peering.

    Required Parameters:
    - name -- The name of the VNet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network vnet peering show", locals())


def list(resource_group, vnet_name):
    '''
    List peerings.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network vnet peering list", locals())


def delete(name, resource_group, vnet_name):
    '''
    Delete a peering.

    Required Parameters:
    - name -- The name of the VNet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network vnet peering delete", locals())


def update(name, resource_group, vnet_name, add=None, force_string=None, remove=None, set=None):
    '''
    Update a peering.

    Required Parameters:
    - name -- The name of the VNet peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network vnet peering update", locals())




'''
Manage Azure Maps account keys.
'''
from .... pyaz_utils import _call_az

def renew(key, name, resource_group):
    '''
    Regenerate either the primary or secondary key for use with the Maps APIs. The old key will stop working immediately.

    Required Parameters:
    - key -- Whether the operation refers to the primary or secondary key
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps account keys renew", locals())


def list(name, resource_group):
    '''
    Get the keys to use with the Maps APIs. A key is used to authenticate and authorize access to the Maps REST APIs. Only one key is needed at a time; two are given to provide seamless key regeneration.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps account keys list", locals())




from ..... pyaz_utils import _call_az

def add(connection_monitor, location, type, workspace_id=None):
    '''
    Add an output to a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - type -- Connection monitor output destination type. Currently, only "Workspace" is supported

    Optional Parameters:
    - workspace_id -- The id of log analytics workspace
    '''
    return _call_az("az network watcher connection-monitor output add", locals())


def remove(connection_monitor, location):
    '''
    Remove all outputs from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network watcher connection-monitor output remove", locals())


def list(connection_monitor, location):
    '''
    List all output from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network watcher connection-monitor output list", locals())




from ... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Get the details for an instance pool.

    Required Parameters:
    - name -- Instance Pool Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql instance-pool show", locals())


def list(resource_group=None):
    '''
    List available instance pools.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql instance-pool list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an instance pool.

    Required Parameters:
    - name -- Instance Pool Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sql instance-pool update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an instance pool.

    Required Parameters:
    - name -- Instance Pool Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql instance-pool delete", locals())


def create(capacity, family, location, name, resource_group, subnet, tier, license_type=None, no_wait=None, tags=None, vnet_name=None):
    '''
    Create an instance pool.

    Required Parameters:
    - capacity -- Capacity of the instance pool in vcores.
    - family -- The compute generation component of the sku. Allowed value: Gen5
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Instance Pool Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of the subnet that allows access to an Instance Pool. If subnet name is provided, --vnet-name must be provided.
    - tier -- The edition component of the sku. Allowed value: GeneralPurpose.

    Optional Parameters:
    - license_type -- The license type to apply for this instance pool.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet_name -- The virtual network name
    '''
    return _call_az("az sql instance-pool create", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for an instance pool to reach a desired state.

    Required Parameters:
    - name -- Instance Pool Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql instance-pool wait", locals())




'''
Manage full HSM restore.
'''
from ... pyaz_utils import _call_az

def start(backup_folder, storage_container_SAS_token, blob_container_name=None, hsm_name=None, id=None, storage_account_name=None, storage_resource_uri=None):
    '''
    Restore a full backup of a HSM.

    Required Parameters:
    - backup_folder -- Name of the blob container which contains the backup
    - storage_container_SAS_token -- The SAS token pointing to an Azure Blob storage container

    Optional Parameters:
    - blob_container_name -- Name of Blob Container.
    - hsm_name -- Name of the HSM. Can be omitted if --id is specified.
    - id -- Full URI of the HSM.
    - storage_account_name -- Name of Azure Storage Account.
    - storage_resource_uri -- Azure Blob storage container Uri. If specified all other 'Storage Id' arguments should be omitted
    '''
    return _call_az("az keyvault restore start", locals())




'''
Manage storage for an Azure Media Services account.
'''
from .... pyaz_utils import _call_az

def add(account_name, name, resource_group):
    '''
    Attach a secondary storage to an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name or resource ID of the secondary storage account to detach from the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account storage add", locals())


def remove(account_name, name, resource_group):
    '''
    Detach a secondary storage from an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name or resource ID of the secondary storage account to detach from the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account storage remove", locals())


def set_authentication(account_name, resource_group, storage_auth):
    '''
    Set the authentication of a storage account attached to an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_auth -- The type of authentication for the storage account associated with the media services account.
    '''
    return _call_az("az ams account storage set-authentication", locals())


def sync_storage_keys(account_name, resource_group, storage_account_id):
    '''
    Synchronize storage account keys for a storage account associated with an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account_id -- The storage account Id.
    '''
    return _call_az("az ams account storage sync-storage-keys", locals())




from ... pyaz_utils import _call_az
from . import version


def list(gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig gallery-application list", locals())


def show(gallery_name, name, resource_group):
    '''
    

    Required Parameters:
    - gallery_name -- gallery name
    - name -- The name of the gallery Application
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig gallery-application show", locals())


def create(gallery_name, name, os_type, resource_group, description=None, location=None, no_wait=None, tags=None):
    '''
    Create a gallery Application Definition.

    Required Parameters:
    - gallery_name -- gallery name
    - name -- The name of the gallery Application
    - os_type -- This property allows you to specify the supported type of the OS that application is built for. <br><br> Possible values are: <br><br> **Windows** <br><br> **Linux**
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - description -- The description of this gallery Application Definition resource. This property is updatable.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sig gallery-application create", locals())


def update(gallery_name, name, resource_group, description=None, location=None, no_wait=None, tags=None):
    '''
    Update a gallery Application Definition.

    Required Parameters:
    - gallery_name -- gallery name
    - name -- The name of the gallery Application
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - description -- The description of this gallery Application Definition resource. This property is updatable.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sig gallery-application update", locals())


def delete(gallery_name, name, resource_group, no_wait=None, yes=None):
    '''
    

    Required Parameters:
    - gallery_name -- gallery name
    - name -- The name of the gallery Application
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sig gallery-application delete", locals())


def wait(gallery_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the sig gallery-application is met.

    Required Parameters:
    - gallery_name -- gallery name
    - name -- The name of the gallery Application
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sig gallery-application wait", locals())




'''
Manage role definitions.
'''
from .... pyaz_utils import _call_az

def list(custom_role_only=None, hsm_name=None, scope=None):
    '''
    

    Optional Parameters:
    - custom_role_only -- Only show custom role definitions.
    - hsm_name -- Name of the HSM.
    - scope -- scope at which the role assignment or definition applies to, e.g., "/" or "/keys" or "/keys/{keyname}"
    '''
    return _call_az("az keyvault role definition list", locals())


def create(hsm_name, role_definition):
    '''
    Create a custom role definition.

    Required Parameters:
    - hsm_name -- Name of the HSM.
    - role_definition -- Description of a role as JSON, or a path to a file containing a JSON description.
    '''
    return _call_az("az keyvault role definition create", locals())


def update(hsm_name, role_definition):
    '''
    Update a role definition.

    Required Parameters:
    - hsm_name -- Name of the HSM.
    - role_definition -- Description of a role as JSON, or a path to a file containing a JSON description.
    '''
    return _call_az("az keyvault role definition update", locals())


def delete(hsm_name, name=None, role_id=None):
    '''
    Delete a role definition.

    Required Parameters:
    - hsm_name -- Name of the HSM.

    Optional Parameters:
    - name -- The role definition name. This is a GUID in the "name" property of a role definition.
    - role_id -- The role definition ID.
    '''
    return _call_az("az keyvault role definition delete", locals())


def show(hsm_name, name=None, role_id=None):
    '''
    Show the details of a role definition.

    Required Parameters:
    - hsm_name -- Name of the HSM.

    Optional Parameters:
    - name -- The role definition name. This is a GUID in the "name" property of a role definition.
    - role_id -- The role definition ID.
    '''
    return _call_az("az keyvault role definition show", locals())




'''
Manage image builder template output distributors.
'''
from .... pyaz_utils import _call_az

def add(name, resource_group, artifact_tags=None, gallery_image_definition=None, gallery_name=None, gallery_replication_regions=None, is_vhd=None, managed_image=None, managed_image_location=None, output_name=None):
    '''
    Add an image builder output distributor to an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - artifact_tags -- Tags that will be applied to the output artifact once it has been created by the distributor. space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - gallery_image_definition -- Name or ID of the existing SIG image definition to create the customized image version with.
    - gallery_name -- Shared image gallery name, if image definition name and not ID was provided.
    - gallery_replication_regions -- Space-separated list of regions to replicate the image version into. Defaults to resource group's location.
    - is_vhd -- The output is a VHD distributor.
    - managed_image -- Name or ID of the customized managed image to be created.
    - managed_image_location -- Location where the customized image will be created. Defaults to resource group's location.
    - output_name -- Name of the image builder run output. Defaults to the name of the managed image or sig image definition.
    '''
    return _call_az("az image builder output add", locals())


def remove(name, output_name, resource_group):
    '''
    Remove an image builder output distributor from an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - output_name -- Name of the image builder run output.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder output remove", locals())


def clear(name, resource_group):
    '''
    Remove all image builder output distributors from an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder output clear", locals())




from .... pyaz_utils import _call_az
from . import action_group, scope


def list(resource_group=None):
    '''
    List activity log alerts under a resource group or the current subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor activity-log alert list", locals())


def create(name, resource_group, action_group=None, condition=None, description=None, disable=None, scope=None, tags=None, webhook_properties=None):
    '''
    Create a default activity log alert

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action_group -- None
    - condition -- None
    - description -- None
    - disable -- None
    - scope -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - webhook_properties -- None
    '''
    return _call_az("az monitor activity-log alert create", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the activity log alert.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor activity-log alert show", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the activity log alert.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor activity-log alert delete", locals())


def update(name, resource_group, add=None, condition=None, description=None, enabled=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update the details of this activity log alert

    Required Parameters:
    - name -- The name of the activity log alert.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - condition -- None
    - description -- None
    - enabled -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor activity-log alert update", locals())




from .... pyaz_utils import _call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Lists all Kusto pool principalAssignments.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool-principal-assignment list", locals())


def show(kusto_pool_name, principal_assignment_name, resource_group, workspace_name):
    '''
    Gets a Kusto pool principalAssignment.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - principal_assignment_name -- The name of the Kusto principalAssignment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto pool-principal-assignment show", locals())


def create(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, no_wait=None, principal_id=None, principal_type=None, role=None, tenant_id=None):
    '''
    Create a Kusto pool principalAssignment.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - principal_assignment_name -- The name of the Kusto principalAssignment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - principal_id -- The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
    - principal_type -- Principal type.
    - role -- Cluster principal role.
    - tenant_id -- The tenant id of the principal
    '''
    return _call_az("az synapse kusto pool-principal-assignment create", locals())


def update(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, add=None, force_string=None, no_wait=None, principal_id=None, principal_type=None, remove=None, role=None, set=None, tenant_id=None):
    '''
    Update a Kusto pool principalAssignment.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - principal_assignment_name -- The name of the Kusto principalAssignment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - principal_id -- The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
    - principal_type -- Principal type.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - role -- Cluster principal role.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tenant_id -- The tenant id of the principal
    '''
    return _call_az("az synapse kusto pool-principal-assignment update", locals())


def delete(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes a Kusto pool principalAssignment.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - principal_assignment_name -- The name of the Kusto principalAssignment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse kusto pool-principal-assignment delete", locals())


def wait(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto pool-principal-assignment is met.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - principal_assignment_name -- The name of the Kusto principalAssignment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse kusto pool-principal-assignment wait", locals())




'''
Manage Azure Cosmos DB SQL role assignments.
'''
from ..... pyaz_utils import _call_az

def create(account_name, principal_id, resource_group, scope, no_wait=None, role_assignment_id=None, role_definition_id=None, role_definition_name=None):
    '''
    Create a SQL role assignment under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - principal_id -- AAD Object ID of the principal to which this Role Assignment is being granted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope -- Data plane resource path at which this Role Assignment is being granted.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.
    - role_definition_id -- Unique ID of the Role Definition that this Role Assignment refers to.
    - role_definition_name -- Unique Name of the Role Definition that this Role Assignment refers to. Eg. 'Contoso Reader Role'.
    '''
    return _call_az("az cosmosdb sql role assignment create", locals())


def update(account_name, resource_group, role_assignment_id, no_wait=None, principal_id=None, role_definition_id=None, role_definition_name=None, scope=None):
    '''
    Update a SQL role assignment under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - principal_id -- AAD Object ID of the principal to which this Role Assignment is being granted.
    - role_definition_id -- Unique ID of the Role Definition that this Role Assignment refers to.
    - role_definition_name -- Unique Name of the Role Definition that this Role Assignment refers to. Eg. 'Contoso Reader Role'.
    - scope -- Data plane resource path at which this Role Assignment is being granted.
    '''
    return _call_az("az cosmosdb sql role assignment update", locals())


def exists(account_name, resource_group, role_assignment_id):
    '''
    Check if an Azure Cosmos DB role assignment exists.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.
    '''
    return _call_az("az cosmosdb sql role assignment exists", locals())


def list(account_name, resource_group):
    '''
    List all SQL role assignments under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql role assignment list", locals())


def show(account_name, resource_group, role_assignment_id):
    '''
    Show the properties of a SQL role assignment under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.
    '''
    return _call_az("az cosmosdb sql role assignment show", locals())


def delete(account_name, resource_group, role_assignment_id, no_wait=None, yes=None):
    '''
    Delete a SQL role assignment under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb sql role assignment delete", locals())


def wait(account_name, resource_group, role_assignment_id, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Poll on a SQL role assignment until a specific condition is met.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role_assignment_id -- Optional for Create. Unique ID for the Role Assignment. If not provided, a new GUID will be used.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az cosmosdb sql role assignment wait", locals())




'''
Manage Spark pools.
'''
from .... pyaz_utils import _call_az

def show(name, resource_group, workspace_name):
    '''
    Get a Spark pool.

    Required Parameters:
    - name -- The name of the Spark pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse spark pool show", locals())


def list(resource_group, workspace_name):
    '''
    List all Spark pools.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse spark pool list", locals())


def create(name, node_count, node_size, resource_group, spark_version, workspace_name, delay=None, enable_auto_pause=None, enable_auto_scale=None, max_node_count=None, min_node_count=None, no_wait=None, node_size_family=None, spark_config_file_path=None, spark_events_folder=None, spark_log_folder=None, tags=None):
    '''
    Create a Spark pool.

    Required Parameters:
    - name -- The name of the Spark pool.
    - node_count -- The number of node.
    - node_size -- The node size.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - spark_version -- The supported Spark version is 2.4 now.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - delay -- The delay time whose unit is minute.
    - enable_auto_pause -- The flag of enabling auto pause.
    - enable_auto_scale -- The flag of enabling auto scale.
    - max_node_count -- The max node count.
    - min_node_count -- The min node count.
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_size_family -- The node size family.
    - spark_config_file_path -- Absolute path of Spark pool properties configuration file.
    - spark_events_folder -- The Spark events folder.
    - spark_log_folder -- The default Spark log folder.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse spark pool create", locals())


def update(name, resource_group, workspace_name, delay=None, enable_auto_pause=None, enable_auto_scale=None, force=None, library_requirements=None, max_node_count=None, min_node_count=None, no_wait=None, node_count=None, node_size=None, package=None, package_action=None, spark_config_file_path=None, tags=None):
    '''
    Update the Spark pool.

    Required Parameters:
    - name -- The name of the Spark pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - delay -- The delay time whose unit is minute.
    - enable_auto_pause -- The flag of enabling auto pause.
    - enable_auto_scale -- The flag of enabling auto scale.
    - force -- The flag of force operation.
    - library_requirements -- The library requirements file.
    - max_node_count -- The max node count.
    - min_node_count -- The min node count.
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_count -- The number of node.
    - node_size -- The node size.
    - package -- List of workspace packages name.
    - package_action -- Package action must be specified when you add or remove a workspace package from a Apache Spark pool.
    - spark_config_file_path -- Absolute path of Spark pool properties configuration file.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse spark pool update", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a Spark pool.

    Required Parameters:
    - name -- The name of the Spark pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse spark pool delete", locals())


def wait(big_data_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a Spark pool is met.

    Required Parameters:
    - big_data_pool_name -- Big Data pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse spark pool wait", locals())




'''
Commands to manage a Kubernetes-orchestrated Azure Container Service.
'''
from ... pyaz_utils import _call_az

def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    '''
    

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disable_browser -- Do not open browser after opening a proxy to the cluster web user interface
    - ssh_key_file -- Path to an SSH key file to use.
    '''
    return _call_az("az acs kubernetes browse", locals())


def get_credentials(name, resource_group, file=None, overwrite_existing=None, ssh_key_file=None):
    '''
    Download and install credentials to access a cluster.  This command requires the same private-key used to create the cluster.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file -- Where to install the kubectl config file
    - overwrite_existing -- If specified, overwrite any existing credentials.
    - ssh_key_file -- Path to an SSH key file to use
    '''
    return _call_az("az acs kubernetes get-credentials", locals())


def install_cli(base_src_url=None, client_version=None, install_location=None, kubelogin_base_src_url=None, kubelogin_install_location=None, kubelogin_version=None):
    '''
    Download and install the Kubernetes command-line tool for a cluster.

    Optional Parameters:
    - base_src_url -- Base download source URL for kubectl releases.
    - client_version -- Version of kubectl to install.
    - install_location -- Path at which to install kubectl.
    - kubelogin_base_src_url -- Base download source URL for kubelogin releases.
    - kubelogin_install_location -- Path at which to install kubelogin.
    - kubelogin_version -- Version of kubelogin to install.
    '''
    return _call_az("az acs kubernetes install-cli", locals())




from ..... pyaz_utils import _call_az

def list(resource_group, workspace_name):
    '''
    List all data export ruleses for a given workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace data-export list", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a data export rule for a given workspace.

    Required Parameters:
    - name -- Name of the data export rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace data-export show", locals())


def create(destination, name, resource_group, tables, workspace_name, enable=None):
    '''
    Create a data export rule for a given workspace.

    Required Parameters:
    - destination -- The destination resource ID. It should be a storage account, an event hub namespace or an event hub. If event hub namespace is provided, event hub would be created for each table automatically.
    - name -- Name of the data export rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tables -- An array of tables to export.
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - enable -- Enable this data export rule.
    '''
    return _call_az("az monitor log-analytics workspace data-export create", locals())


def update(name, resource_group, tables, workspace_name, add=None, destination=None, enable=None, force_string=None, remove=None, set=None):
    '''
    Update a data export rule for a given workspace.

    Required Parameters:
    - name -- Name of the data export rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tables -- An array of tables to export.
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - destination -- The destination resource ID. It should be a storage account, an event hub namespace or an event hub. If event hub namespace is provided, event hub would be created for each table automatically.
    - enable -- Enable this data export rule.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az monitor log-analytics workspace data-export update", locals())


def delete(name, resource_group, workspace_name, yes=None):
    '''
    Delete a data export rule for a given workspace.

    Required Parameters:
    - name -- Name of the data export rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor log-analytics workspace data-export delete", locals())




'''
Manage the node instance of a cluster.
'''
from .... pyaz_utils import _call_az

def add(cluster_name, node_type, number_of_nodes_to_add, resource_group):
    '''
    Add nodes to a node type in a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_type -- the Node type name.
    - number_of_nodes_to_add -- number of nodes to add.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf cluster node add", locals())


def remove(cluster_name, node_type, number_of_nodes_to_remove, resource_group):
    '''
    Remove nodes from a node type in a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_type -- the Node type name.
    - number_of_nodes_to_remove -- number of nodes to remove.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf cluster node remove", locals())




'''
Manage classic metric-based alert rules.
'''
from ... pyaz_utils import _call_az

def create(condition, name, target, action=None, description=None, disabled=None, email_service_owners=None, location=None, resource_group=None, tags=None, target_namespace=None, target_parent=None, target_type=None):
    '''
    Create a classic metric-based alert rule.

    Required Parameters:
    - condition -- None
    - name -- Name of the alert rule.
    - target -- Name or ID of the target resource.

    Optional Parameters:
    - action -- None
    - description -- None
    - disabled -- None
    - email_service_owners -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_namespace -- Target resource provider namespace.
    - target_parent -- Target resource parent path, if applicable.
    - target_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor alert create", locals())


def delete(name, resource_group):
    '''
    Delete an alert rule.

    Required Parameters:
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor alert delete", locals())


def show(name, resource_group):
    '''
    Show an alert rule.

    Required Parameters:
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor alert show", locals())


def list(resource_group):
    '''
    List alert rules in a resource group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor alert list", locals())


def show_incident(name, resource_group, rule_name):
    '''
    Get the details of an alert rule incident.

    Required Parameters:
    - name -- The name of the incident to retrieve.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the alert rule.
    '''
    return _call_az("az monitor alert show-incident", locals())


def list_incidents(resource_group, rule_name):
    '''
    List all incidents for an alert rule.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the alert rule.
    '''
    return _call_az("az monitor alert list-incidents", locals())


def update(name, add=None, add_action=None, aggregation=None, condition=None, description=None, email_service_owners=None, enabled=None, force_string=None, metric=None, operator=None, period=None, remove=None, remove_action=None, resource=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, set=None, tags=None, threshold=None):
    '''
    Update a classic metric-based alert rule.

    Required Parameters:
    - name -- Name of the alert rule.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - add_action -- None
    - aggregation -- None
    - condition -- None
    - description -- None
    - email_service_owners -- None
    - enabled -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - metric -- None
    - operator -- None
    - period -- None
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - remove_action -- None
    - resource -- Name or ID of the target resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - threshold -- None
    '''
    return _call_az("az monitor alert update", locals())

